@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"log"
+	"strings"
 	"time"
 
 	"github.com/pkg/errors"
@@ -124,6 +125,21 @@ func printBackupList(cn *pbm.PBM, size int64) {
 	if err != nil {
 		log.Fatalln("Error: unable to get backups list:", err)
 	}
+
+	inf, err := cn.GetNodeInfo()
+	if err != nil {
+		log.Fatalln("Error: define cluster state", err)
+	}
+
+	shards, err := cn.ClusterMembers(inf)
+	if err != nil {
+		log.Fatalln("Error: get cluster members", err)
+	}
+
+	// pbm.PBM is always connected either to config server or to the sole (hence main) RS
+	// which the `confsrv` param in `bcpMatchCluster` is all about
+	bcpMatchCluster(bcps, shards, inf.SetName)
+
 	fmt.Println("Backup snapshots:")
 	for i := len(bcps) - 1; i >= 0; i-- {
 		b := bcps[i]
@@ -136,24 +152,61 @@ func printBackupList(cn *pbm.PBM, size int64) {
 	}
 }
 
+// bcpMatchCluster checks if given backups match shards in the cluster. Match means that
+// each replset in backup have respective replset on the target cluster. It's ok if cluster
+// has more shards than there are currently in backup. But in the case of sharded cluster
+// backup has to have data for the current config server or for the sole RS in case of non-sharded rs.
+//
+// If some backup doesn't match cluster, the status of the backup meta in given `bcps` would be
+// changed to pbm.StatusError with respective error text emitted. It doesn't change meta on
+// storage nor in DB (backup is ok, it just doesn't cluster), it is just "in-flight" changes
+// in given `bcps`.
+func bcpMatchCluster(bcps []pbm.BackupMeta, shards []pbm.Shard, confsrv string) {
+	sh := make(map[string]struct{}, len(shards))
+	for _, s := range shards {
+		sh[s.RS] = struct{}{}
+	}
+
+	var nomatch []string
+	for i := 0; i < len(bcps); i++ {
+		bcp := &bcps[i]
+		nomatch = nomatch[:0]
+		hasconfsrv := false
+		for _, rs := range bcp.Replsets {
+			if _, ok := sh[rs.Name]; !ok {
+				nomatch = append(nomatch, rs.Name)
+			}
+			if rs.Name == confsrv {
+				hasconfsrv = true
+			}
+		}
+
+		if len(nomatch) > 0 {
+			bcp.Error = "Backup doesn't match current cluster topology - it has different replica set names. " +
+				"Extra shards in the backup will cause this, for a simple example. " +
+				"The extra/unknown replica set names found in the backup are: " + strings.Join(nomatch, ", ")
+			bcp.Status = pbm.StatusError
+		}
+
+		if !hasconfsrv {
+			if bcp.Error != "" {
+				bcp.Error += ". "
+			}
+			bcp.Error += "Backup has no data for the config server or sole replicaset"
+			bcp.Status = pbm.StatusError
+		}
+	}
+}
+
 func printPITR(cn *pbm.PBM, size int, full bool) {
 	on, err := cn.IsPITR()
 	if err != nil {
 		log.Fatalf("Error: check if PITR is on: %v", err)
 	}
 
-	inf, err := cn.GetNodeInfo()
+	shards, err := cn.ClusterMembers(nil)
 	if err != nil {
-		log.Fatalf("Error: define cluster state: %v", err)
-	}
-
-	shards := []pbm.Shard{{RS: inf.SetName}}
-	if inf.IsSharded() {
-		s, err := cn.GetShards()
-		if err != nil {
-			log.Fatalf("Error: get shards: %v", err)
-		}
-		shards = append(shards, s...)
+		log.Fatalf("Error: get cluster members: %v", err)
 	}
 
 	now := time.Now().Unix()
