@@ -96,8 +96,8 @@ func main() {
 	}
 
 	if *mURL == "" {
-		log.Println("Error: no mongodb connection URI supplied\n")
-		log.Println("       Usual practice is the set it by the PBM_MONGODB_URI environment variable. It can also be set with commandline argument --mongodb-uri.\n")
+		log.Println("Error: no mongodb connection URI supplied")
+		log.Println("       Usual practice is the set it by the PBM_MONGODB_URI environment variable. It can also be set with commandline argument --mongodb-uri.")
 		pbmCmd.Usage(os.Args[1:])
 		os.Exit(1)
 	}
@@ -217,6 +217,13 @@ func main() {
 		if *listCmdRestore {
 			printRestoreList(pbmClient, *listCmdSize, *listCmdFullF)
 		} else {
+			// show message ans skip when resync is running
+			lk, err := findLock(pbmClient, pbmClient.GetLocks)
+			if err == nil && lk != nil && lk.Type == pbm.CmdResyncBackupList {
+				fmt.Println("[Storage resync is running. Backups list will be available after sync finishes.]")
+				return
+			}
+
 			printBackupList(pbmClient, *listCmdSize)
 			printPITR(pbmClient, int(*listCmdSize), *listCmdFullF)
 		}
