@@ -197,7 +197,7 @@ install_deps() {
           yum -y install rpm-build make rpmlint rpmdevtools golang git
       else
           yum -y install epel-release git
-          yum -y install rpmbuild rpm-build make rpmlint rpmdevtools golang
+          yum -y install rpmbuild rpm-build make rpmlint rpmdevtools golang krb5-devel
       fi
       install_golang
     else
@@ -208,7 +208,7 @@ install_deps() {
       DEBIAN_FRONTEND=noninteractive apt-get -y install lsb_release
       export DEBIAN=$(lsb_release -sc)
       export ARCH=$(echo $(uname -m) | sed -e 's:i686:i386:g')
-      INSTALL_LIST="wget devscripts debhelper debconf pkg-config curl make golang git"
+      INSTALL_LIST="wget devscripts debhelper debconf pkg-config curl make golang git libkrb5-dev"
       until DEBIAN_FRONTEND=noninteractive apt-get -y install ${INSTALL_LIST}; do
         sleep 1
         echo "waiting"
