@@ -54,6 +54,11 @@ func (p *PBM) ResyncStorage(l *log.Event) error {
 		if err != nil {
 			return errors.Wrap(err, "unmarshal backup meta")
 		}
+		err = checkBackupFiles(&v, stg)
+		if err != nil {
+			l.Warning("skip snapshot %s: %v", v.Name, err)
+			continue
+		}
 		ins = append(ins, v)
 	}
 	_, err = p.Conn.Database(DB).Collection(BcpCollection).InsertMany(p.ctx, ins)
@@ -71,12 +76,12 @@ func (p *PBM) ResyncStorage(l *log.Event) error {
 
 	var pitr []interface{}
 	for _, f := range pitrf {
-		_, err := stg.FileStat(PITRfsPrefix + "/" + f)
+		_, err := stg.FileStat(PITRfsPrefix + "/" + f.Name)
 		if err != nil {
 			l.Warning("skip %s because of %v", f, err)
 			continue
 		}
-		chnk := PITRmetaFromFName(f)
+		chnk := PITRmetaFromFName(f.Name)
 		if chnk != nil {
 			pitr = append(pitr, chnk)
 		}
@@ -94,6 +99,28 @@ func (p *PBM) ResyncStorage(l *log.Event) error {
 	return nil
 }
 
+func checkBackupFiles(bcp *BackupMeta, stg storage.Storage) error {
+	for _, rs := range bcp.Replsets {
+		f, err := stg.FileStat(rs.DumpName)
+		if err != nil {
+			return errors.Wrapf(err, "file %s", rs.DumpName)
+		}
+		if f.Size == 0 {
+			return errors.Errorf("%s is empty", rs.DumpName)
+		}
+
+		f, err = stg.FileStat(rs.OplogName)
+		if err != nil {
+			return errors.Wrapf(err, "file %s", rs.OplogName)
+		}
+		if f.Size == 0 {
+			return errors.Errorf("%s is empty", rs.OplogName)
+		}
+	}
+
+	return nil
+}
+
 func (p *PBM) moveCollection(coll, as string) error {
 	err := p.Conn.Database(DB).Collection(as).Drop(p.ctx)
 	if err != nil {
