@@ -9,6 +9,7 @@ import (
 var ErrNotExist = errors.New("no such file")
 
 type FileInfo struct {
+	Name string // with path
 	Size int64
 }
 
@@ -17,7 +18,7 @@ type Storage interface {
 	SourceReader(name string) (io.ReadCloser, error)
 	// FileStat returns file info. It returns error if file is empty or not exists
 	FileStat(name string) (FileInfo, error)
-	List(prefix string) ([]string, error)
+	List(prefix string) ([]FileInfo, error)
 	Files(suffix string) ([][]byte, error)
 	// Delete deletes given file.
 	// It returns storage.ErrNotExist if a file isn't exists
